Module rt_format::argument [−][src]
Defines traits and types to help make arbitrary values formattable at runtime.
Structs
Holds a FormatArgument and implements all the std::fmt formatting traits.
A NamedArguments implementation that always returns None.
A ’PositionalArgumentsimplementation that always returnsNone`.
Traits
A source of values to use when parsing the formatting string.
A type that indicates whether its value supports a specific format, and provides formatting functions that correspond to different format types.
A type that associates an argument with a name.
A type that provides a list of arguments, randomly accessible by their position.