Trait rt_format::argument::PositionalArguments[][src]

pub trait PositionalArguments<'v, V> where
    V: 'v + FormatArgument
{ type Iter: Iterator<Item = &'v V>; fn get(&self, index: usize) -> Option<&V>;
fn iter(&'v self) -> Self::Iter; }
A type that provides a list of arguments, randomly accessible by their position.

Associated Types

The type of the iterator that can be used to iterate over arguments.

Required methods

Returns a reference to the argument at the given index, if any.

Creates an iterator over the arguments.

Implementors