pub struct NoMap;
A Map implementation that always returns None.
Map
None
Returns a reference to the value associated with the given key, if any.
Gets the TypeId of self. Read more
TypeId
self
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Performs the conversion.
The type returned in the event of a conversion error.