Trait rt_format::map::Map[][src]

pub trait Map<Q, V> where
    Q: Hash + Eq + ?Sized
{ fn get(&self, key: &Q) -> Option<&V>; }
A type that associates a value with a key.

Required methods

Returns a reference to the value associated with the given key, if any.

Implementations on Foreign Types

Implementors