Provides support for parsing typical Rust formatting strings.

The parser supports all of the features of the formatting strings that are normally passed to the format! macro, except for the fill character.

Structs

A representation of the formatting string and associated values, ready to be formatted.

An iterator of Segments that correspond to the parts of the formatting string being parsed.

A value and its formatting specifier.

Enums

A single segment of a formatting string.

Traits

A type conversion into usize that might fail. Like TryInto<usize>, but does not consume self. The parser needs this trait to support formats whose width or precision use “dollar syntax”. For more information about these, see std::fmt.

Functions

Parses only the format specifier portion of a format argument. For example, in a format argument specification {foo:#X}, this function would parse only the #X part.