Struct rt_format::parser::ParsedFormat [−][src]
pub struct ParsedFormat<'a, V: FormatArgument> {
pub segments: Vec<Segment<'a, V>>,
}Expand description
A representation of the formatting string and associated values, ready to be formatted.
Fields
segments: Vec<Segment<'a, V>>A vector of formatting string segments.
Implementations
pub fn parse<P, N>(
format: &'a str,
positional: &'a P,
named: &'a N
) -> Result<Self, usize> where
P: PositionalArguments<'a, V> + ?Sized,
N: NamedArguments<V>,
pub fn parse<P, N>(
format: &'a str,
positional: &'a P,
named: &'a N
) -> Result<Self, usize> where
P: PositionalArguments<'a, V> + ?Sized,
N: NamedArguments<V>,
Parses the formatting string, using given positional and named arguments. Does not perform any formatting. It just parses the formatting string, validates that all the arguments are present, and that each argument supports the requested format.