Trait rt_format::parser::ConvertToSize [−][src]
A type conversion into usize that might fail, similar to TryInto. Does not consume self.
A type conversion into usize that might fail, similar to TryInto. Does not consume self.