pub trait ArgumentSource<V> where
    V: FormatArgument
{ fn next_argument(&mut self) -> Option<&V>;
fn lookup_argument_by_index(&self, idx: usize) -> Option<&V>;
fn lookup_argument_by_name(&self, name: &str) -> Option<&V>; }
A source of values to use when parsing the formatting string.

Required methods

Returns the next positional argument, if any. Calling lookup_argument_by_index does not affect which value will be returned by the next call to next_argument.

Returns the positional argument with the given index, if any. Calling lookup_argument_by_index does not affect which value will be returned by the next call to next_argument.

Returns the named argument with the given name, if any.

Implementors