pub trait Map<Q, V> where Q: Hash + Eq + ?Sized, { fn get(&self, key: &Q) -> Option<&V>; }
A type that associates a value with a key.
Returns a reference to the value associated with the given key, if any.