Trait Map
Other items inrt_format::map
pub trait Map<Q: ?Sized, V> where Q: Hash + Eq, { fn get(&self, key: &Q) -> Option<&V>; }
A type that associates a value with a key.
fn get(&self, key: &Q) -> Option<&V>
Returns a reference to the value associated with the given key, if any.
impl<K, Q: ?Sized, V> Map<Q, V> for HashMap<K, V> where Q: Hash + Eq, K: Borrow<Q> + Hash + Eq,
impl<K, Q: ?Sized, V> Map<Q, V> for HashMap<K, &V> where Q: Hash + Eq, K: Borrow<Q> + Hash + Eq,
impl<Q: ?Sized, V> Map<Q, V> for NoMap where Q: Hash + Eq,