Module rt_format::parser [−][src]
Provides support for parsing typical Rust formatting strings.
The parser supports all of the features of the formatting strings that are normally passed to
the format! macro, except for the fill character.
Structs
An iterator of Segments that correspond to the parts of the formatting string being parsed.
Traits
A type conversion into usize that might fail, similar to TryInto. Does not consume self.